easy_api_annotations library

Canonical entry point for the easy_api_annotations package.

Re-exports all annotations and types from mcp_annotations.dart so that consumers can follow the standard convention of importing package:easy_api_annotations/easy_api_annotations.dart.

The legacy import package:easy_api_annotations/mcp_annotations.dart continues to work for backward compatibility.

Classes

Parameter
Annotation to provide rich metadata for individual parameters in a Tool.
Server
Annotation to mark a class, library, or method for server generation.
Tool
Annotation that describes an MCP tool.
ToolAnnotations
Metadata hints that describe a Tool's behavior to MCP clients.

Enums

McpTransport
Transport protocol options for MCP servers.