mcp_annotations library

MCP annotations package

Provides annotations used to expose library methods as tools in the Model Context Protocol (MCP) server.

Classes

Parameter
Annotation to provide rich metadata for individual parameters in a Tool.
Prompt
Annotation to mark a method as an MCP prompt template.
PromptArgument
Annotation to provide rich metadata for individual arguments in a Prompt.
Server
Annotation to mark a class, library, or method for server generation.
Tool
Annotation that describes an MCP tool.
ToolAnnotations
Metadata hints that describe a Tool's behavior to MCP clients.

Enums

McpTransport
Transport protocol options for MCP servers.