example property
Example value for this parameter.
Shown to users as a hint for the expected format or value. Helps LLMs understand the expected input format.
Implementation
final Object? example;
Example value for this parameter.
Shown to users as a hint for the expected format or value. Helps LLMs understand the expected input format.
final Object? example;