pattern property
Regular expression pattern for string validation.
When provided, the parameter value must match this pattern.
Implementation
final String? pattern;
Regular expression pattern for string validation.
When provided, the parameter value must match this pattern.
final String? pattern;