title property
Human-readable title for this parameter.
Displayed as the label in MCP clients. If not provided, the parameter name will be used.
Implementation
final String? title;
Human-readable title for this parameter.
Displayed as the label in MCP clients. If not provided, the parameter name will be used.
final String? title;