name property
Custom name for this prompt.
If provided, this name is used instead of the method name. Must be unique within the MCP server.
Implementation
final String? name;
Custom name for this prompt.
If provided, this name is used instead of the method name. Must be unique within the MCP server.
final String? name;