title property
Human-readable title for this prompt.
Displayed in MCP clients (e.g., as a slash command label). If not provided, the prompt name will be used.
Implementation
final String? title;
Human-readable title for this prompt.
Displayed in MCP clients (e.g., as a slash command label). If not provided, the prompt name will be used.
final String? title;