description property
Detailed description of what this argument represents.
Provides context to help users understand what value to provide.
Implementation
final String? description;
Detailed description of what this argument represents.
Provides context to help users understand what value to provide.
final String? description;