required property
Whether this argument is required.
If not provided, the generator infers requirement from Dart nullability: non-nullable parameters are required, nullable parameters are optional.
Implementation
final bool? required;
Whether this argument is required.
If not provided, the generator infers requirement from Dart nullability: non-nullable parameters are required, nullable parameters are optional.
final bool? required;