title property
Human-readable title for this argument.
Displayed as the label in MCP clients. If not provided, the argument name will be used.
Implementation
final String? title;
Human-readable title for this argument.
Displayed as the label in MCP clients. If not provided, the argument name will be used.
final String? title;