codeModeTimeout property
Maximum execution time in seconds for code mode scripts.
Only used when codeMode is true. If a script exceeds this timeout, the sandbox process is forcefully terminated and an error is returned.
Defaults to 30 seconds.
Implementation
final int codeModeTimeout;