description property
Optional text describing what this tool does.
If not provided, the generator will use the method's dartdoc comment. This description is shown to users in MCP clients.
Implementation
final String? description;
Optional text describing what this tool does.
If not provided, the generator will use the method's dartdoc comment. This description is shown to users in MCP clients.
final String? description;