name property

String? name
final

Optional custom name for this tool.

If provided, this name is used instead of the method name. Useful for avoiding naming collisions or creating more descriptive tool names. Must be unique within the MCP server.

Implementation

final String? name;