destructiveHint property
If true, the tool may perform destructive updates to its environment.
Only meaningful when readOnlyHint is false. Defaults to true
when omitted (conservative assumption).
Implementation
final bool? destructiveHint;
If true, the tool may perform destructive updates to its environment.
Only meaningful when readOnlyHint is false. Defaults to true
when omitted (conservative assumption).
final bool? destructiveHint;