idempotentHint property

bool? idempotentHint
final

If true, calling the tool repeatedly with the same arguments will have no additional effect on its environment.

Only meaningful when readOnlyHint is false. Defaults to false when omitted.

Implementation

final bool? idempotentHint;