readOnlyHint property
If true, the tool does not modify its environment.
Read-only tools are safe to call without side-effects. Defaults to
false when omitted.
Implementation
final bool? readOnlyHint;
If true, the tool does not modify its environment.
Read-only tools are safe to call without side-effects. Defaults to
false when omitted.
final bool? readOnlyHint;