AudioPromptContent class

Audio content for a prompt message.

Includes audio information in the prompt as a base64-encoded audio file with an associated MIME type.

Example:

PromptMessage(
  role: PromptRole.user,
  content: AudioPromptContent(base64AudioData, 'audio/wav'),
)
Inheritance

Constructors

AudioPromptContent(String data, String mimeType)
Creates audio content.
const

Properties

data String
Base64-encoded audio data.
final
hashCode int
The hash code for this object.
no setterinherited
mimeType String
MIME type of the audio (e.g., 'audio/wav', 'audio/mp3').
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited