ImagePromptContent class
Image content for a prompt message.
Includes visual information in the prompt as a base64-encoded image with an associated MIME type.
Example:
PromptMessage(
role: PromptRole.user,
content: ImagePromptContent(base64Data, 'image/png'),
)
- Inheritance
-
- Object
- PromptContent
- ImagePromptContent
Constructors
- ImagePromptContent(String data, String mimeType)
-
Creates image content.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited