TextPromptContent class
Text content for a prompt message.
This is the most common content type, representing plain text that will be sent to the language model.
Example:
PromptMessage(
role: PromptRole.user,
content: TextPromptContent('Please review this code: $code'),
)
- Inheritance
-
- Object
- PromptContent
- TextPromptContent
Constructors
- TextPromptContent(String text)
-
Creates text content.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited