mcp_annotations library
MCP annotations package
Provides annotations used to expose library methods as tools in the Model Context Protocol (MCP) server.
Classes
Enums
- McpTransport
- Transport protocol options for MCP servers.
MCP annotations package
Provides annotations used to expose library methods as tools in the Model Context Protocol (MCP) server.