McpTransport enum

Transport protocol options for MCP servers.

Determines how the generated MCP server will communicate with clients.

Inheritance
Available extensions

Values

stdio → const McpTransport

Communicate via standard input/output using JSON-RPC protocol.

This is the default transport and is suitable for CLI-based MCP clients.

http → const McpTransport

Run an HTTP server using the shelf package.

This transport allows remote clients to connect via HTTP requests.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<McpTransport>
A constant List of the values in this enum, in order of their declaration.