description property
Description of what this prompt does.
Shown to users to help them understand when to use this prompt. If not provided, the generator will use the method's dartdoc comment.
Implementation
final String? description;
Description of what this prompt does.
Shown to users to help them understand when to use this prompt. If not provided, the generator will use the method's dartdoc comment.
final String? description;