AudioPromptContent class
Audio content for a prompt message.
Includes audio information in the prompt as a base64-encoded audio file with an associated MIME type.
Example:
PromptMessage(
role: PromptRole.user,
content: AudioPromptContent(base64AudioData, 'audio/wav'),
)
- Inheritance
-
- Object
- PromptContent
- AudioPromptContent
Constructors
- AudioPromptContent(String data, String mimeType)
-
Creates audio content.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited