ImagePromptContent class

Image content for a prompt message.

Includes visual information in the prompt as a base64-encoded image with an associated MIME type.

Example:

PromptMessage(
  role: PromptRole.user,
  content: ImagePromptContent(base64Data, 'image/png'),
)
Inheritance

Constructors

ImagePromptContent(String data, String mimeType)
Creates image content.
const

Properties

data String
Base64-encoded image data.
final
hashCode int
The hash code for this object.
no setterinherited
mimeType String
MIME type of the image (e.g., 'image/png', 'image/jpeg').
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited