TextPromptContent class

Text content for a prompt message.

This is the most common content type, representing plain text that will be sent to the language model.

Example:

PromptMessage(
  role: PromptRole.user,
  content: TextPromptContent('Please review this code: $code'),
)
Inheritance

Constructors

TextPromptContent(String text)
Creates text content.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The text content.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited